<?php
namespace Ems\portalGestor\Service;

use Ems\portalGestor\Service\PeriodoService;
use Ems\portalGestor\Util\HcmServices;

class ReportService {
    /** @var HcmServices */
    protected $hcmServices;

    /** @var PeriodoService */
    protected $periodoService;

    public function __construct(
        HcmServices $hcmServices,
        PeriodoService $periodoService
    ) {
        $this->hcmServices = $hcmServices;
        $this->periodoService = $periodoService;
    }

    public function generateBirtReport(
        array $row
    ): string {
        $nrOrg = (int) $row['NRORG'];
        $hcmServicesRoute = 'generateBirtReport';

        $nrPeriodo = $row['P_PERIODO'] ?? null;
        $nrVinculo = $row['P_VINCULO'] ?? null;

        if (isset($nrPeriodo) && isset($nrVinculo)) {
            $row['P_PERIODO'] = $this->periodoService->getNrPeriodoEquivalente(
                $nrOrg, $nrVinculo, $nrPeriodo
            );
        }

        $params = [
            'requestType' => 'Row',
            'row' => $row
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $reportLink = (string) $response['dataset'][$hcmServicesRoute]['link'];

        return $reportLink;
    }

    public function downloadReport(
        int $nrOrg,
        string $link
    ): array {
        $hcmServicesRoute = 'downloadReport';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'link' => $link
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $reportLink = (array) $response['dataset'][$hcmServicesRoute];

        return $reportLink;
    }

}
